module Hermes
  module Statuses
    class HousingApplication < Base
      def self.list
        {
          commission: [
            'EN ATTENTE',
            'PLO',
            'TRANSMIS BAILLEUR',
            'ACCEPTEE EN CAL',
            'REFUSEE EN CAL',
            'NON RETENUE',
            'NON RETENUE EN CAL',
            'LOGE',
            'DESISTEMENT SALARIE AVANT CAL',
            'ANNULEE BAILLEUR',
            'DESISTEMENT',
            'ANNULEE',
            "A L'ETUDE ALS",
            'DESISTEMENT APRES CAL'
          ],
          visit: [
            'VISITE PROPOSEE',
            'VISITE EFFECTUEE',
            'DESISTEMENT APRES VISITE',
            'ACCORD APRES VISITE'
          ],
        }
      end

      def self.correspondence(original_status)
        case original_status.upcase
        when 'WAITING'
          'EN ATTENTE'

        when 'ATTRIBUTION LOT AVEC RANG'
          'ACCEPTEE EN CAL'

        when 'INSCRIPTION CAL'
          'TRANSMIS BAILLEUR'

        when 'ATTRIBUTION LOT'
          'ACCEPTEE EN CAL'

        when 'ATTRIBUTION SOUS CONDITION'
          'ACCEPTEE EN CAL'

        when 'VISITE PROPOSEE'
          'ACCEPTEE EN CAL'

        when 'VISITE EFFECTUEE'
          'ACCEPTEE EN CAL'

        when 'REFUS ATTRIBUTION'
          'REFUSEE EN CAL'

        when 'REFUS LOT DEMANDEUR'
          'NON RETENUE'

        when 'RADIATION ATTRIBUTION'
          'NON RETENUE EN CAL'

        else
          I18n.transliterate(original_status).upcase
        end
      end

      def self.sopra_code(status)
        code = ""
        case I18n.transliterate(status).upcase
        when 'INSCRIPTION CAL', 'TRANSMIS BAILLEUR'
          code = "INSCAL"
        when 'ATTRIBUTION LOT AVEC RANG', 'ACCEPTEE EN CAL'
          code = "DESCAL"
        when 'ATTRIBUTION LOT'
          code = "DESCAL01"
        when 'ATTRIBUTION SOUS CONDITION'
          code = "DESCAL02"
        when 'REFUS ATTRIBUTION', 'REFUSEE EN CAL'
          code = "DESCAL03"
        when 'REFUS LOT DEMANDEUR', 'NON RETENUE'
          code = "REFLOG"
        when 'VISITE PROPOSEE'
          code = "VISPRO"
        when 'VISITE EFFECTUEE'
          code = "VISEFF"
        when 'RADIATION ATTRIBUTION'
          code = "RADATT", 'NON RETENUE EN CAL'
        end

        code
      end
    end
  end
end